@@ -10,8 +10,6 @@ Public interface for student training:
 
 import logging
 
-import six
-
 from django.db import DatabaseError
 from django.utils.translation import ugettext as _
 
@@ -169,8 +167,8 @@ def validate_training_examples(rubric, examples):
     # Construct a list of valid options for each criterion
     try:
         criteria_options = {
-            six.text_type(criterion['name']): [
-                six.text_type(option['name'])
+            str(criterion['name']): [
+                str(option['name'])
                 for option in criterion['options']
             ]
             for criterion in rubric['criteria']
@@ -184,7 +182,7 @@ def validate_training_examples(rubric, examples):
     # then it doesn't make sense to do student training.
     criteria_without_options = [
         criterion_name
-        for criterion_name, criterion_option_list in six.iteritems(criteria_options)
+        for criterion_name, criterion_option_list in criteria_options.items()
         if len(criterion_option_list) == 0
     ]
     if not (set(criteria_options) - set(criteria_without_options)):
@@ -210,7 +208,7 @@ def validate_training_examples(rubric, examples):
         else:
             # Check each selected option in the example (one per criterion)
             options_selected = example_dict['options_selected']
-            for criterion_name, option_name in six.iteritems(options_selected):
+            for criterion_name, option_name in options_selected.items():
                 if criterion_name in criteria_options:
                     valid_options = criteria_options[criterion_name]
                     if option_name not in valid_options:
